@@ -1,7 +1,6 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
-#include "settings.h"
-#include <QtGui>
+
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -20,6 +19,7 @@ MainWindow::MainWindow(QWidget *parent) :
     mediaObject = new Phonon::MediaObject(this);
     audioOutput = new Phonon::AudioOutput(Phonon::MusicCategory, this);
     mediaPath = Phonon::createPath(mediaObject, audioOutput);
+    mediaObject->play();
 }
 
 MainWindow::~MainWindow()
@@ -78,13 +78,7 @@ void MainWindow::update()
 
     formatTimer(timerSeconds);
 
-//    ui->labelTest->setText(QString::number(mvTime.elapsed()));
-
-    if (timerSeconds == 0) {
-//        mvpTimer->stop();
-//        mvCountDown = 0;
-//        ui->pushButton_start->setText("Start");
-//        mvStarted = 0;
+    if (timerSeconds == 0 && !mvTimeUp) {
         timeUp();
     }
 }
@@ -98,6 +92,7 @@ void MainWindow::formatTimer(int timerSeconds)
 
 void MainWindow::setTimer(int timerSeconds)
 {
+    mediaObject->stop();
     mvpTimer->stop();
     timerColour(false);
     mvTimeUp = false;
@@ -134,7 +129,7 @@ void MainWindow::timeUp()
     mediaObject->play();
     mvTimeUp = true;
     mvTime.restart();
-    mvCountDown = 1;
+    mvCountDown = 0;
 }
 
 void MainWindow::timerColour(bool timerRed)
@@ -157,6 +152,11 @@ void MainWindow::on_pushButton_start_clicked()
     case 0:
         mvTimeUp = false;
         timerColour(false);
+        if (mvCountDown != 0) {
+            mvTimeUp = false;
+        } else {
+            mvTimeUp = true;
+        }
         mvTime.start();
         update();
         mvpTimer->start(100);
@@ -248,6 +248,12 @@ void MainWindow::on_actionAbout_triggered()
 
 void MainWindow::on_actionDonate_triggered()
 {
-    QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=sascha.makela@gmail.com&lc=LT&item_name=STM%20Software%20%2d%20Countdown%20Timer&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted"));
+    QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=sascha.makela@gmail.com&lc=LT&item_name=STM%20Software%20-%20Countdown%20Timer&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted"));
 //    QDesktopServices::openUrl(QUrl("http://www.google.com"));
 }
+
+void MainWindow::on_actionHelp_triggered()
+{
+    helpDialog = new Help;
+    helpDialog->exec();
+}
